@@ -128,7 +128,7 @@ class Exceptions:
 
 class CodePipelineClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html)
     """
 
@@ -145,7 +145,7 @@ class CodePipelineClient(BaseClient):
         Returns information about a specified job and whether that job has been received
         by the job worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#acknowledge_job)
         """
 
@@ -155,7 +155,7 @@ class CodePipelineClient(BaseClient):
         """
         Confirms a job worker has received the specified job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.acknowledge_third_party_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#acknowledge_third_party_job)
         """
 
@@ -163,7 +163,7 @@ class CodePipelineClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#can_paginate)
         """
 
@@ -175,25 +175,25 @@ class CodePipelineClient(BaseClient):
         version: str,
         inputArtifactDetails: "ArtifactDetailsTypeDef",
         outputArtifactDetails: "ArtifactDetailsTypeDef",
-        settings: "ActionTypeSettingsTypeDef" = None,
-        configurationProperties: Sequence["ActionConfigurationPropertyTypeDef"] = None,
-        tags: Sequence["TagTypeDef"] = None
+        settings: "ActionTypeSettingsTypeDef" = ...,
+        configurationProperties: Sequence["ActionConfigurationPropertyTypeDef"] = ...,
+        tags: Sequence["TagTypeDef"] = ...
     ) -> CreateCustomActionTypeOutputTypeDef:
         """
         Creates a new custom action that can be used in all pipelines associated with
         the AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#create_custom_action_type)
         """
 
     def create_pipeline(
-        self, *, pipeline: "PipelineDeclarationTypeDef", tags: Sequence["TagTypeDef"] = None
+        self, *, pipeline: "PipelineDeclarationTypeDef", tags: Sequence["TagTypeDef"] = ...
     ) -> CreatePipelineOutputTypeDef:
         """
         Creates a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#create_pipeline)
         """
 
@@ -203,7 +203,7 @@ class CodePipelineClient(BaseClient):
         """
         Marks a custom action as deleted.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.delete_custom_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_custom_action_type)
         """
 
@@ -211,7 +211,7 @@ class CodePipelineClient(BaseClient):
         """
         Deletes the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_pipeline)
         """
 
@@ -219,16 +219,16 @@ class CodePipelineClient(BaseClient):
         """
         Deletes a previously created webhook by name.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.delete_webhook)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#delete_webhook)
         """
 
-    def deregister_webhook_with_third_party(self, *, webhookName: str = None) -> Dict[str, Any]:
+    def deregister_webhook_with_third_party(self, *, webhookName: str = ...) -> Dict[str, Any]:
         """
         Removes the connection between the webhook that was created by CodePipeline and
         the external tool with events to be detected.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.deregister_webhook_with_third_party)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#deregister_webhook_with_third_party)
         """
 
@@ -244,7 +244,7 @@ class CodePipelineClient(BaseClient):
         Prevents artifacts in a pipeline from transitioning to the next stage in the
         pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.disable_stage_transition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#disable_stage_transition)
         """
 
@@ -254,21 +254,21 @@ class CodePipelineClient(BaseClient):
         """
         Enables artifacts in a pipeline to transition to a stage in a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.enable_stage_transition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#enable_stage_transition)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#generate_presigned_url)
         """
 
@@ -279,7 +279,7 @@ class CodePipelineClient(BaseClient):
         Returns information about an action type created for an external provider, where
         the action is to be used by customers of the external provider.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.get_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_action_type)
         """
 
@@ -287,15 +287,15 @@ class CodePipelineClient(BaseClient):
         """
         Returns information about a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.get_job_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_job_details)
         """
 
-    def get_pipeline(self, *, name: str, version: int = None) -> GetPipelineOutputTypeDef:
+    def get_pipeline(self, *, name: str, version: int = ...) -> GetPipelineOutputTypeDef:
         """
         Returns the metadata, structure, stages, and actions of a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline)
         """
 
@@ -307,7 +307,7 @@ class CodePipelineClient(BaseClient):
         artifacts, the pipeline execution ID, and the name, version, and status of the
         pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline_execution)
         """
 
@@ -316,7 +316,7 @@ class CodePipelineClient(BaseClient):
         Returns information about the state of a pipeline, including the stages and
         actions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.get_pipeline_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_pipeline_state)
         """
 
@@ -326,7 +326,7 @@ class CodePipelineClient(BaseClient):
         """
         Requests the details of a job for a third party action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.get_third_party_job_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#get_third_party_job_details)
         """
 
@@ -334,69 +334,69 @@ class CodePipelineClient(BaseClient):
         self,
         *,
         pipelineName: str,
-        filter: "ActionExecutionFilterTypeDef" = None,
-        maxResults: int = None,
-        nextToken: str = None
+        filter: "ActionExecutionFilterTypeDef" = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> ListActionExecutionsOutputTypeDef:
         """
         Lists the action executions that have occurred in a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.list_action_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_action_executions)
         """
 
     def list_action_types(
         self,
         *,
-        actionOwnerFilter: ActionOwnerType = None,
-        nextToken: str = None,
-        regionFilter: str = None
+        actionOwnerFilter: ActionOwnerType = ...,
+        nextToken: str = ...,
+        regionFilter: str = ...
     ) -> ListActionTypesOutputTypeDef:
         """
         Gets a summary of all AWS CodePipeline action types associated with your
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.list_action_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_action_types)
         """
 
     def list_pipeline_executions(
-        self, *, pipelineName: str, maxResults: int = None, nextToken: str = None
+        self, *, pipelineName: str, maxResults: int = ..., nextToken: str = ...
     ) -> ListPipelineExecutionsOutputTypeDef:
         """
         Gets a summary of the most recent executions for a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.list_pipeline_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_pipeline_executions)
         """
 
     def list_pipelines(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> ListPipelinesOutputTypeDef:
         """
         Gets a summary of all of the pipelines associated with your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_pipelines)
         """
 
     def list_tags_for_resource(
-        self, *, resourceArn: str, nextToken: str = None, maxResults: int = None
+        self, *, resourceArn: str, nextToken: str = ..., maxResults: int = ...
     ) -> ListTagsForResourceOutputTypeDef:
         """
         Gets the set of key-value pairs (metadata) that are used to manage the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_tags_for_resource)
         """
 
     def list_webhooks(
-        self, *, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListWebhooksOutputTypeDef:
         """
         Gets a listing of all the webhooks in this AWS Region for this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.list_webhooks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#list_webhooks)
         """
 
@@ -404,23 +404,23 @@ class CodePipelineClient(BaseClient):
         self,
         *,
         actionTypeId: "ActionTypeIdTypeDef",
-        maxBatchSize: int = None,
-        queryParam: Mapping[str, str] = None
+        maxBatchSize: int = ...,
+        queryParam: Mapping[str, str] = ...
     ) -> PollForJobsOutputTypeDef:
         """
         Returns information about any jobs for AWS CodePipeline to act on.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.poll_for_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#poll_for_jobs)
         """
 
     def poll_for_third_party_jobs(
-        self, *, actionTypeId: "ActionTypeIdTypeDef", maxBatchSize: int = None
+        self, *, actionTypeId: "ActionTypeIdTypeDef", maxBatchSize: int = ...
     ) -> PollForThirdPartyJobsOutputTypeDef:
         """
         Determines whether there are any third party jobs for a job worker to act on.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#poll_for_third_party_jobs)
         """
 
@@ -435,7 +435,7 @@ class CodePipelineClient(BaseClient):
         """
         Provides information to AWS CodePipeline about new revisions to a source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_action_revision)
         """
 
@@ -451,7 +451,7 @@ class CodePipelineClient(BaseClient):
         """
         Provides the response to a manual approval request to AWS CodePipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.put_approval_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_approval_result)
         """
 
@@ -461,7 +461,7 @@ class CodePipelineClient(BaseClient):
         """
         Represents the failure of a job as returned to the pipeline by a job worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.put_job_failure_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_job_failure_result)
         """
 
@@ -469,15 +469,15 @@ class CodePipelineClient(BaseClient):
         self,
         *,
         jobId: str,
-        currentRevision: "CurrentRevisionTypeDef" = None,
-        continuationToken: str = None,
-        executionDetails: "ExecutionDetailsTypeDef" = None,
-        outputVariables: Mapping[str, str] = None
+        currentRevision: "CurrentRevisionTypeDef" = ...,
+        continuationToken: str = ...,
+        executionDetails: "ExecutionDetailsTypeDef" = ...,
+        outputVariables: Mapping[str, str] = ...
     ) -> None:
         """
         Represents the success of a job as returned to the pipeline by a job worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.put_job_success_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_job_success_result)
         """
 
@@ -488,7 +488,7 @@ class CodePipelineClient(BaseClient):
         Represents the failure of a third party job as returned to the pipeline by a job
         worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_failure_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_third_party_job_failure_result)
         """
 
@@ -497,34 +497,34 @@ class CodePipelineClient(BaseClient):
         *,
         jobId: str,
         clientToken: str,
-        currentRevision: "CurrentRevisionTypeDef" = None,
-        continuationToken: str = None,
-        executionDetails: "ExecutionDetailsTypeDef" = None
+        currentRevision: "CurrentRevisionTypeDef" = ...,
+        continuationToken: str = ...,
+        executionDetails: "ExecutionDetailsTypeDef" = ...
     ) -> None:
         """
         Represents the success of a third party job as returned to the pipeline by a job
         worker.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.put_third_party_job_success_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_third_party_job_success_result)
         """
 
     def put_webhook(
-        self, *, webhook: "WebhookDefinitionTypeDef", tags: Sequence["TagTypeDef"] = None
+        self, *, webhook: "WebhookDefinitionTypeDef", tags: Sequence["TagTypeDef"] = ...
     ) -> PutWebhookOutputTypeDef:
         """
         Defines a webhook and returns a unique webhook URL generated by CodePipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#put_webhook)
         """
 
-    def register_webhook_with_third_party(self, *, webhookName: str = None) -> Dict[str, Any]:
+    def register_webhook_with_third_party(self, *, webhookName: str = ...) -> Dict[str, Any]:
         """
         Configures a connection between the webhook that was created and the external
         tool with events to be detected.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.register_webhook_with_third_party)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#register_webhook_with_third_party)
         """
 
@@ -539,32 +539,27 @@ class CodePipelineClient(BaseClient):
         """
         Resumes the pipeline execution by retrying the last failed actions in a stage.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.retry_stage_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#retry_stage_execution)
         """
 
     def start_pipeline_execution(
-        self, *, name: str, clientRequestToken: str = None
+        self, *, name: str, clientRequestToken: str = ...
     ) -> StartPipelineExecutionOutputTypeDef:
         """
         Starts the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.start_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#start_pipeline_execution)
         """
 
     def stop_pipeline_execution(
-        self,
-        *,
-        pipelineName: str,
-        pipelineExecutionId: str,
-        abandon: bool = None,
-        reason: str = None
+        self, *, pipelineName: str, pipelineExecutionId: str, abandon: bool = ..., reason: str = ...
     ) -> StopPipelineExecutionOutputTypeDef:
         """
         Stops the specified pipeline execution.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#stop_pipeline_execution)
         """
 
@@ -572,7 +567,7 @@ class CodePipelineClient(BaseClient):
         """
         Adds to or modifies the tags of the given resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#tag_resource)
         """
 
@@ -580,7 +575,7 @@ class CodePipelineClient(BaseClient):
         """
         Removes tags from an AWS resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#untag_resource)
         """
 
@@ -589,7 +584,7 @@ class CodePipelineClient(BaseClient):
         Updates an action type that was created with any supported integration model,
         where the action type is to be used by customers of the action type provider.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.update_action_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.update_action_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#update_action_type)
         """
 
@@ -599,7 +594,7 @@ class CodePipelineClient(BaseClient):
         """
         Updates a specified pipeline with edits or changes to its structure.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/client.html#update_pipeline)
         """
 
@@ -608,7 +603,7 @@ class CodePipelineClient(BaseClient):
         self, operation_name: Literal["list_action_executions"]
     ) -> ListActionExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionExecutions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactionexecutionspaginator)
         """
 
@@ -617,7 +612,7 @@ class CodePipelineClient(BaseClient):
         self, operation_name: Literal["list_action_types"]
     ) -> ListActionTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Paginator.ListActionTypes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listactiontypespaginator)
         """
 
@@ -626,14 +621,14 @@ class CodePipelineClient(BaseClient):
         self, operation_name: Literal["list_pipeline_executions"]
     ) -> ListPipelineExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelineExecutions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelineexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Paginator.ListPipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listpipelinespaginator)
         """
 
@@ -642,13 +637,13 @@ class CodePipelineClient(BaseClient):
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Paginator.ListTagsForResource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listtagsforresourcepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_webhooks"]) -> ListWebhooksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/codepipeline.html#CodePipeline.Paginator.ListWebhooks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codepipeline/paginators.html#listwebhookspaginator)
         """
